import React from "react";
import { QueryClient, QueryClientProvider } from "react-query";

function createCtx() {
  const ctx = /*#__PURE__*/React.createContext(undefined);

  function useCtx() {
    const c = React.useContext(ctx);
    if (c === undefined) throw new Error("useCtx must be inside a Provider with a value");
    return c;
  }

  return [useCtx, ctx.Provider]; // 'as const' makes TypeScript infer a tuple
}

const [useFirestore, FirestoreProvider] = createCtx();
const queryClient = new QueryClient();

const ReactQueryFirestoreProvider = ({
  children,
  reactQueryConfig,
  firestore
}) => {
  queryClient.setDefaultOptions(reactQueryConfig || {});
  return /*#__PURE__*/React.createElement(FirestoreProvider, {
    value: {
      firestore
    }
  }, /*#__PURE__*/React.createElement(QueryClientProvider, {
    client: queryClient
  }, children));
};

export { useFirestore, ReactQueryFirestoreProvider };
//# sourceMappingURL=Provider.js.map